@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.19_01';
+  our $VERSION = '0.19_02';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -66,16 +66,17 @@ package Art::World {
     }
   }
 
-  # Dunno how but the fact of being collected should bump artist reputation
   role Collectionable {
     has owner (
       lazy    => true,
       is      => rw,
       clearer => true,
       writer  => 'set_owner',
+      trigger => sub { shift->status('sold') },
       type    => ArrayRef[ Agent ]) = $self->creator;
     has value  ( is   => rw );
     has status (
+      is              => rw,
       enum            => ['for_sale', 'sold'],
       # Create a delegated method for each value in the enumeration
       handles         => 1,
@@ -100,6 +101,15 @@ package Art::World {
       }
     }
 
+    method $bump_fame_after_sale {
+      # Bump creator reputation
+      foreach ( $self->creator->@* ) {
+        $_->bump_fame;
+      };
+      # Bump artwork aura
+      $self->bump_fame;
+    }
+
     multi method change_owner ( Collector $buyer ) {
 
       # From seller collection
@@ -108,7 +118,8 @@ package Art::World {
       $self->clear_owner;
       $self->set_owner([ $buyer ]);
       push $buyer->collection->@*, $self;
-      # TODO guess it should bump some people reputation and artwork aura now
+
+      $self->$bump_fame_after_sale();
     }
 
     multi method change_owner ( Coinvestor $buyers ) {
@@ -120,7 +131,8 @@ package Art::World {
       $self->clear_owner;
       $self->set_owner( $buyers->members );
       push $buyers->collection->@*, $self;
-      # TODO guess it should bump some people reputation and artwork aura now
+
+      $self->$bump_fame_after_sale();
     }
   }
 
@@ -165,7 +177,7 @@ package Art::World {
         'aura' : 'reputation';
       if ( $self->can( $attribute )) {
         if ( $self->$attribute + $difference >= 0 ) {
-          $self->$attribute( $self->$attribute + $difference )
+          $self->$attribute( $self->$attribute + $difference );
         } else {
           carp 'You tried to update ' . $attribute . ' to a value smaller ' .
             'than zero. Nothing changed.';
@@ -248,6 +260,8 @@ package Art::World {
       # Buyer gives the money
       $self->money( $self->money - $must_give );
     }
+
+    method sell {}
   }
 
   role Showable {
@@ -438,7 +452,7 @@ package Art::World {
       }
 
       class Director with Manager {
-        class Gallerist {}
+        class Gallerist with Market {}
       };
 
       class Public with Unserializable? {
@@ -463,7 +477,7 @@ package Art::World {
         type => Str );
 
       # Same as Agent->reputation
-      has aura( is => rw, type => PositiveOrZeroNum );
+      has aura( is => rw, type => PositiveOrZeroNum ) = 0;
 
       class Article
 
@@ -585,7 +599,7 @@ member procede to a paiement from the C<Co-investors> point of view.
 
 =head2 Collectionable
 
-The C<collectionnable> provide a series of attributes for the ownership and
+The C<collectionnable> role provide a series of attributes for the ownership and
 collectionability of artworks.
 
 If it's collectionable, it can go to a C<Collector> collection or in a
@@ -596,7 +610,7 @@ C<Collectors> or C<Coinvestors> as an unique parameter. It takes care of setting
 appropriately the new artwork owners and delegate the removal of the item from
 the seller's collection.
 
-A private methode, C<$remove_from_seller_collection> is also available to take
+A private method, C<$remove_from_seller_collection> is also available to take
 care of the removal of the I<to-be-sold> C<Artwork> in the seller collection.
 Since those can be owned by many persons, and that C<Artists> can own their own
 artworks, but for now cannot be collectors, they are excluded from this
@@ -989,7 +1003,7 @@ Sébastien Feugère <sebastien@feugere.net>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to everyone who has contributed to ack in any way, including Adrien
+Thanks to everyone who has contributed to Art::World in any way, including Adrien
 Lucca, Toby Inkster, Ezgi Göç, Pierre Aubert, Seb. Hu-Rillettes, Joseph Balicki,
 Nicolas Herubel and Nadia Boursin-Piraud.
 
